import os
from glob import glob
from setuptools import find_namespace_packages, setup
from setuptools.command.build_py import build_py as _build_py


# From https://github.com/pypa/setuptools/pull/1574
class build_py(_build_py):
    def find_package_modules(self, package, package_dir):
        modules = super().find_package_modules(package, package_dir)
        patterns = self._get_platform_patterns(
            self.exclude_package_data,
            package,
            package_dir,
        )

        excluded_module_files = []
        for pattern in patterns:
            excluded_module_files.extend(glob(pattern))

        for f in excluded_module_files:
            for module in modules:
                if module[2] == f:
                    modules.remove(module)
        return modules


os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    packages=find_namespace_packages(),
    include_package_data=True,
    exclude_package_data={
        "": ["configuration.py", "django-admin.py", "build/*"]
    },
    cmdclass={"build_py": build_py},
)



from httpx import AsyncClient
from django.contrib.auth.decorators import login_required
from django.views.decorators.http import require_GET
from django.http import HttpResponseForbidden
from django.http import HttpResponse
from django.conf import settings

ALLOWED_DOMAINS = {
    "search.gesis.org": True,
    "api.datacite.org": True,
    "api.crossref.org": True,
    "zenon.dainst.org": True,
    "eutils.ncbi.nlm.nih.gov": True,
}

PUBMED_API_KEY = getattr(settings, "PUBMED_API_KEY", False)


@login_required
@require_GET
async def proxy(request, url):
    domain = url.split("/")[2]
    if domain not in ALLOWED_DOMAINS:
        return HttpResponseForbidden()
    query_string = request.META["QUERY_STRING"]
    if domain == "api.crossref.org":
        mailto = f"mailto={settings.CONTACT_EMAIL}"
        if len(query_string):
            query_string += "&" + mailto
        else:
            query_string = mailto
    elif domain == "eutils.ncbi.nlm.nih.gov" and PUBMED_API_KEY:
        if len(query_string):
            query_string += f"&api_key={PUBMED_API_KEY}"
        else:
            query_string = f"api_key={PUBMED_API_KEY}"
    if len(query_string):
        url = f"{url}?{query_string}"
    async with AsyncClient() as client:
        response = await client.get(
            url,
            headers={
                "User-Agent": request.META.get(
                    "HTTP_USER_AGENT", "Fidus Writer"
                ),
                "Referer": request.META.get("HTTP_REFERER", ""),
                "Accept": request.META.get("HTTP_ACCEPT", "application/json"),
            },
            timeout=88,  # Firefox times out after 90 seconds, so we need to return before that.
        )
    return HttpResponse(response.text, status=response.status_code)
